    .. _write_a_backend:

Write a backend
---------------

If you are interested in writing your own custom backend, then you could learn
how to do it with those simple examples presented here. Currently you have two
options, you can use the low level tools directly from
:ref:`backend <coherence.backend>` or you could use the tools from
:ref:`models <coherence.backends.models (package)>` which will simplify a
little the building process and you will end up with less lines of code, but by
reading the first method you will get a better idea of what is happening behind
the second method...so...you will have a better understanding of the Cohen3
tools by reading both:

    - :ref:`Using backend directly - The old way <example_backend_the_old_way>`
    - :ref:`Using the models module - The new way <example_backend_the_new_way>`

.. toctree::
    :hidden:

    example_backend_the_old_way
    example_backend_the_new_way